<script src="{{ 'assets/pymdownx-extras/material-extra-theme-8d50d708.js' | url }}" type="text/javascript"></script>
<script src="{{ 'assets/pymdownx-extras/material-extra-3rdparty-a81e7739.js' | url }}" type="text/javascript"></script>
